@@ -4,7 +4,10 @@ from __future__ import print_function
 from __future__ import unicode_literals
 from builtins import super
 from builtins import str
-from future import standard_library
+import warnings
+with warnings.catch_warnings():
+    warnings.simplefilter("ignore")
+    from future import standard_library
 standard_library.install_aliases()
 try:
     from collections.abc import Sequence
@@ -18,8 +21,8 @@ from gcloud.rest.datastore import value
 
 
 # https://cloud.google.com/datastore/docs/reference/data/rest/v1/projects/runQuery#ArrayValue
-class Array(Sequence):
-    def __init__(self, items           )        :
+class Array(Sequence):  # type: ignore[type-arg]
+    def __init__(self, items                   )        :
         super(Sequence, self).__init__()  # pylint: disable=bad-super-call
         self.items = items
 
@@ -39,7 +42,7 @@ class Array(Sequence):
 
     @classmethod
     def from_repr(cls, data                )           :
-        return cls([value.Value.from_repr(x) for x in data['values']])
+        return cls([value.Value.from_repr(x) for x in data.get('values', [])])
 
     def to_repr(self)                  :
         return {'values': [x.to_repr() for x in self]}
