@@ -4,7 +4,10 @@ from __future__ import print_function
 from __future__ import unicode_literals
 from builtins import str
 from builtins import int
-from future import standard_library
+import warnings
+with warnings.catch_warnings():
+    warnings.simplefilter("ignore")
+    from future import standard_library
 standard_library.install_aliases()
 from builtins import object
 from typing import Any
@@ -41,12 +44,12 @@ class Query(BaseQuery):
     # pylint: disable=too-many-instance-attributes
     json_key = 'query'
 
-    def __init__(self, kind      = '', query_filter         = None,
-                 order                      = None, start_cursor      = '',
-                 end_cursor      = '', offset                = None,
-                 limit                = None,
-                 projection                   = None,
-                 distinct_on            = None)        :
+    def __init__(self, kind      = '', query_filter                   = None,
+                 order                                = None,
+                 start_cursor      = '', end_cursor      = '',
+                 offset                = None, limit                = None,
+                 projection                             = None,
+                 distinct_on                      = None)        :
         self.kind = kind
         self.query_filter = query_filter
         self.orders = order or []
@@ -68,6 +71,10 @@ class Query(BaseQuery):
     @classmethod
     def from_repr(cls, data                )           :
         kind = data['kind'] or ''  # Kind is required
+        if not isinstance(kind, str):
+            # If 'kind' is not a str, then the only other acceptable format
+            # is the list of a single dict [{'name' : kind}] (see to_repr)
+            kind = kind[0].get('name') or ''
         orders = [PropertyOrder.from_repr(o) for o in data.get('order', [])]
         start_cursor = data.get('startCursor') or ''
         end_cursor = data.get('endCursor') or ''
@@ -86,7 +93,9 @@ class Query(BaseQuery):
                    projection=projection, distinct_on=distinct_on)
 
     def to_repr(self)                  :
-        data = {'kind': [{'name': self.kind}] if self.kind else []}
+        data                 = {
+            'kind': [{'name': self.kind}] if self.kind else [],
+        }
         if self.query_filter:
             data['filter'] = self.query_filter.to_repr()
         if self.orders:
@@ -111,8 +120,8 @@ class GQLQuery(BaseQuery):
     json_key = 'gqlQuery'
 
     def __init__(self, query_string     , allow_literals       = True,
-                 named_bindings                 = None,
-                 positional_bindings            = None)        :
+                 named_bindings                           = None,
+                 positional_bindings                      = None)        :
         self.query_string = query_string
         self.allow_literals = allow_literals
         self.named_bindings = named_bindings or {}
@@ -156,7 +165,7 @@ class QueryResultBatch(object):
 
     def __init__(self, end_cursor     ,
                  entity_result_type             = ResultType.UNSPECIFIED,
-                 entity_results                     = None,
+                 entity_results                               = None,
                  more_results                  = MoreResultsType.UNSPECIFIED,
                  skipped_cursor      = '', skipped_results      = 0,
                  snapshot_version      = '')        :
